@@ -15,7 +15,9 @@
     if(!is.matrix(x) && !is.data.frame(x)) stop('Data must either be a data frame or a matrix')
     nvar <- dim(x)[2]
     nsub <- dim(x)[1]
+    response.freq <- NULL
     if (nsub !=nvar)  {
+         response.freq <- response.frequencies(x)
          C <- cov(x,use="pairwise") 
          if(!is.null(keys)) {
          			keys<- as.vector(keys)
@@ -31,7 +33,7 @@
          R <- cov2cor(C)
          drop.item <-list()
          alpha.total <- alpha.1(C,R)
-         if(nvar>2) {
+         if(nvar > 2) {
          for (i in 1:nvar) {
          drop.item[[i]] <- alpha.1(C[-i,-i,drop=FALSE],R[-i,-i,drop=FALSE])
                             } 
@@ -47,6 +49,15 @@
         diag(RC) <-smc(R)
         Vtc <- sum(RC)
         item.rc <-colSums(RC)/sqrt(Vtc)
+     #yet one more way to correct is to correlate item with rest of scale
+      if(nvar > 1) {
+      r.drop <- rep(0,nvar)
+        for (i in 1:nvar) { v.drop <- sum(C[-i,-i,drop=FALSE])
+          c.drop <- sum(C[,i]) - C[i,i]
+          r.drop[i] <- c.drop/sqrt(C[i,i]*v.drop)
+              }
+      }
+     
      #  
         item.means <- colMeans(x, na.rm=na.rm )
         item.sd <-  SD(x,na.rm=na.rm)
@@ -54,7 +65,7 @@
         	alpha.total <- data.frame(alpha.total,mean=mean.t,sd=sdev)
         	colnames(alpha.total) <- c("raw_alpha","std.alpha","G6(smc)","average_r","mean","sd")
         	rownames(alpha.total) <- ""
-        	stats <- data.frame(n=t.valid,r =item.r,r.cor = item.rc,mean=item.means,sd=item.sd)} else {
+        	stats <- data.frame(n=t.valid,r =item.r,r.cor = item.rc,r.drop = r.drop,mean=item.means,sd=item.sd)} else {
         	alpha.total <- data.frame(alpha.total)
         	        colnames(alpha.total) <- c("raw_alpha","std.alpha","G6(smc)" ,"average_r")
         	        rownames(alpha.total) <- ""
@@ -62,9 +73,10 @@
                   stats <- data.frame(r =item.r,r.cor = item.rc)
         	}
        	rownames(stats) <- colnames(x)
-        result <- list(total=alpha.total,alpha.drop=by.item,item.stats=stats,call=cl,title=title)
+       	
+        result <- list(total=alpha.total,alpha.drop=by.item,item.stats=stats,response.freq=response.freq,call=cl,title=title)
         class(result) <- c("psych","alpha")
         return(result)
      
     }
-    
+  #modified Sept 8, 2010 to add r.drop feature  
